@@ -1,5 +1,4 @@
 import argparse
-import sys
 
 from faker import Faker
 
@@ -9,7 +8,7 @@ fake = Faker()
 
 def process_args(args):
     n_samples = args.n
-    n_batches = args.b
+    # n_batches = args.b
     outfile = args.outfile
 
     with open(outfile, "w") as name_file:
@@ -27,9 +26,7 @@ def setup_argparse():
     parser = argparse.ArgumentParser("Generate some names!")
     parser.add_argument("-n", help="number of names", default=100, type=int)
     parser.add_argument("-b", help="number of batches of names", default=5, type=int)
-    parser.add_argument(
-        "-outfile", help="name of output .csv file", default="samples.csv"
-    )
+    parser.add_argument("-outfile", help="name of output .csv file", default="samples.csv")
     return parser
 
 
@@ -40,4 +37,4 @@ def main():
 
 
 if __name__ == "__main__":
-    sys.exit(main())
+    main()
