@@ -14,9 +14,7 @@ def error_override_vars(override_vars, spec_filepath):
     original_text = open(spec_filepath, "r").read()
     for variable in override_vars.keys():
         if variable not in original_text:
-            raise ValueError(
-                f"Command line override variable '{variable}' not found in spec file '{spec_filepath}'."
-            )
+            raise ValueError(f"Command line override variable '{variable}' not found in spec file '{spec_filepath}'.")
 
 
 def replace_override_vars(env, override_vars):
